# How to package a Python 3.x project?

Detailed documentation of setup utilities maintained by [Python org](https://packaging.python.org/en/latest/distributing/)

* Step 1: How to create a distributable library or an executable?
* Step 2: How to add non-code files to the package?
* Step 3: How to execute post-install steps on the target machine like setting up a cron job